@@ -199,12 +199,11 @@ class Searcher(object):
                 yield (score, item)
 
     def _newHeap(self, query, curHeap):
-        return sorted(self._ranker(self.ranker(query), curHeap)) 
+        return list(self._ranker(self.ranker(query), curHeap)) 
 
     def _topItems(self, heap, N):
         items = []
-        for i, (_, item) in enumerate(heap):
-            if i == N: break
+        for (_, item) in heapq.nsmallest(N, heap):
             items.append(item)
         return items
 
@@ -232,9 +231,9 @@ class Searcher(object):
             else :
                 # Selected
                 if nextchar == '\r':
-                    h = curHeaps[-1]
+                    h = self._topItems(curHeaps[-1], selected + 1)
                     try:
-                        return h[selected][1]
+                        return h[selected]
                     except IndexError:
                         return None
 
